@@ -332,6 +332,7 @@ QString WireGuardInterfaceWidget::supportedFileExtensions()
 void WireGuardInterfaceWidget::showPeers()
 {
     QPointer<WireGuardTabWidget> peers = new WireGuardTabWidget(d->peers, this);
+    peers->setAttribute(Qt::WA_DeleteOnClose);
 
     connect(peers.data(), &WireGuardTabWidget::accepted, [peers, this]() {
         NMVariantMapList peersData = peers->setting();
@@ -343,11 +344,6 @@ void WireGuardInterfaceWidget::showPeers()
             slotWidgetChanged();
         }
     });
-    connect(peers.data(), &WireGuardTabWidget::finished, [peers]() {
-        if (peers) {
-            peers->deleteLater();
-        }
-    });
     peers->setModal(true);
     peers->show();
 }
