@@ -21,8 +21,8 @@ public:
     Ui::FortisslvpnWidget ui;
     Ui::FortisslvpnAdvancedWidget advUi;
     NetworkManager::VpnSetting::Ptr setting;
-    QDialog *advancedDlg;
-    QWidget *advancedWid;
+    QDialog *advancedDlg = nullptr;
+    QWidget *advancedWid = nullptr;
 };
 
 FortisslvpnWidget::FortisslvpnWidget(const NetworkManager::VpnSetting::Ptr &setting, QWidget *parent, Qt::WindowFlags f)
@@ -50,10 +50,10 @@ FortisslvpnWidget::FortisslvpnWidget(const NetworkManager::VpnSetting::Ptr &sett
     d->advancedDlg = new QDialog(this);
     d->advancedWid = new QWidget(this);
     d->advUi.setupUi(d->advancedWid);
-    QVBoxLayout *layout = new QVBoxLayout(d->advancedDlg);
+    auto layout = new QVBoxLayout(d->advancedDlg);
     layout->addWidget(d->advancedWid);
     d->advancedDlg->setLayout(layout);
-    QDialogButtonBox *buttons = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, d->advancedDlg);
+    auto buttons = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, d->advancedDlg);
     connect(buttons, &QDialogButtonBox::accepted, d->advancedDlg, &QDialog::accept);
     connect(buttons, &QDialogButtonBox::rejected, d->advancedDlg, &QDialog::reject);
     layout->addWidget(buttons);
